# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][keepachangelog] and this project
adheres to [Semantic Versioning][semver].

## [Unreleased][unreleased]

## [0.9.1][v0.9.1] - 2017-09-21
### Deprecated
 - Added deprecation warning about changing token file format from `shelve`
   to JSON in next release. Because of that the file will need to be
   regenerated (#4)

## [0.9.0][v0.9.0] - 2017-09-17
### Added
- Started keeping a changelog

### Changed
- Major test suite overhaul
- Code cleanup


[keepachangelog]: http://keepachangelog.com/en/1.0.0/
[semver]: http://semver.org/spec/v2.0.0.html
[unreleased]: https://github.com/pawelad/pymonzo/compare/v0.9.1...HEAD
[v0.9.0]: https://github.com/pawelad/pymonzo/releases/tag/v0.9.0
[v0.9.1]: https://github.com/pawelad/pymonzo/releases/tag/v0.9.1
